<?php

namespace Drupal\Tests\entity_share_client\Functional;

use Drupal\Component\Serialization\Json;
use Drupal\node\NodeInterface;

/**
 * General functional test class.
 *
 * @group entity_share
 * @group entity_share_client
 */
class EntityShareClientFunctionalTest extends EntityShareClientFunctionalTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $entityTypeId = 'node';

  /**
   * {@inheritdoc}
   */
  protected static $entityBundleId = 'es_test';

  /**
   * {@inheritdoc}
   */
  protected static $entityLangcode = 'en';

  /**
   * {@inheritdoc}
   */
  protected function getEntitiesDataArray() {
    return [
      'node' => [
        'en' => [
          'es_test' => [
            'type' => [
              'value' => static::$entityBundleId,
              'checker_callback' => 'getTargetId',
            ],
            'title' => [
              'value' => $this->randomString(),
              'checker_callback' => 'getValue',
            ],
            'status' => [
              'value' => NodeInterface::PUBLISHED,
              'checker_callback' => 'getValue',
            ],
          ],
        ],
      ],
    ];
  }

  /**
   * Test basic pull feature.
   */
  public function testBasicPull() {
    // TODO: improve the import.
    $channel_infos = $this->remoteManager->getChannelsInfos($this->remote);
    $this->jsonapiHelper->setRemote($this->remote);
    $http_client = $this->remoteManager->prepareJsonApiClient($this->remote);

    foreach ($this->channels as $channel) {
      $channel_url = $channel_infos[$channel->id()]['url'];
      while ($channel_url) {
        $response = $this->requestService->request($http_client, 'GET', $channel_url);
        $json = Json::decode((string) $response->getBody());

        $this->jsonapiHelper->importEntityListData($this->jsonapiHelper->prepareData($json['data']));

        if (isset($json['links']['next']['href'])) {
          $channel_url = $json['links']['next']['href'];
        }
        else {
          $channel_url = FALSE;
        }
      }
    }

    $this->checkCreatedEntities();
  }

}
